@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class InvoiceConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    name = "tuhls_invoice.invoice"
+    name = "tuhls_invoice"
